==> archibald-7.x-2.0.tar.gz: archibald/js/prohibit_double_edit.js <==
var archibald_prohibit_double_edit_interval=0;

/**
 * ping for updating editor last seen bit
 * will called by interval every 3 minutes
 **/
function archibald_prohibit_double_edit_ping()
{
    jQuery.get(Drupal.settings.archibald_prohibit_double_edit.url_ping, function() { } );
}

(function ($) {

Drupal.behaviors.archibald_prohibit_double_edit = {
  attach: function (context, settings) {
    archibald_prohibit_double_edit(settings);

    if (Drupal.settings.archibald_prohibit_double_edit.form_blur_message==true) {
        archibald_form_blur_message();
    }
  }
};

/**
* check if resource is currently edited by other user
* by using Drupal.settings
* and display message dialog in case
* or start interval ping to update editor last seen bit in db
*/
function archibald_prohibit_double_edit(settings) {
    if (settings.archibald_prohibit_double_edit.free!=1) {
        var last_seen = new Date(settings.archibald_prohibit_double_edit.last_seen*1000);

        archibald_prohibit_double_edit_dialog( Drupal.t('User: "@username" <br> is editing this node since <br> "@time"',
              { '@username': settings.archibald_prohibit_double_edit.user,
                '@time':     last_seen.toLocaleString()
              } )
             );

    } else {
        archibald_prohibit_double_edit_init();
    }
}

/**
 * start ping interval
 * to update editor last seen bit in db
 **/
function archibald_prohibit_double_edit_init() {
    archibald_prohibit_double_edit_ping();

    if (archibald_prohibit_double_edit_interval==undefined) {
        // work arround for for ajax initer
        return false;
    }

    // ping alle 3 Minutes that you still edit this node
    archibald_prohibit_double_edit_interval = window.setInterval("archibald_prohibit_double_edit_ping()", (1000*60*3));

    $('.archibald_form_submit').click(archibald_prohibit_double_edit_checkout); // form save button
    $('.tabs .primary li span' ).click(archibald_prohibit_double_edit_checkout); // primary tabs like "view", "translate", "delete" ,"revisions"

    $(window).unload(function() {
        archibald_prohibit_double_edit_checkout();
    });
}

/**
 * reset editor last seen bit
 * call this wenn leveing editing mode
 **/
function archibald_prohibit_double_edit_checkout()
{
    $.get(Drupal.settings.archibald_prohibit_double_edit.url_checkout, function() { } );

    window.clearInterval(archibald_prohibit_double_edit_interval);
    archibald_prohibit_double_edit_interval = 0;
}

/**
 * dsiplay a info dialog
 * with history.back() on closing
 *
 * @param message strng
 */
function archibald_prohibit_double_edit_dialog( message )
{
    var dialog_div = $('<div></div>');
    dialog_div.attr('title', Drupal.t('double editing info'));

    dialog_div.append('<p>'+message+'</p>');

    var dialog_buttons = new Object();
    dialog_buttons[Drupal.t('back')] = function() {
        window.history.back();
      };

    dialog_div.dialog({ buttons:dialog_buttons, modal:true });

    dialog_div.bind( "dialogbeforeclose", function(event, ui) {
        window.history.back();
        return false;
      });
}

/**
 *  display warning when user leave withou saving
 *  This will only work in modern versions of InternetExplorer and Firefox
 *  @see https://developer.mozilla.org/en/DOM/window.onbeforeunload
 */
function archibald_form_blur_message() {
    $('#archibald-content-form input').bind('change',    function () { $(window).bind('beforeunload' ,archibald_form_blur_message_unload_msg); } );
    $('#archibald-content-form textarea').bind('change', function () { $(window).bind('beforeunload' ,archibald_form_blur_message_unload_msg); } );
    $('#archibald-content-form select').bind('change',   function () { $(window).bind('beforeunload' ,archibald_form_blur_message_unload_msg); } );

    $('.archibald_form_submit').click( function () {  $(window).unbind('beforeunload');  } );

    function archibald_form_blur_message_unload_msg(e) {
        e = e || window.event;

        var msg = Drupal.t('Do you realy like to leave without saving?');
        if (e) {
            e.returnValue = msg;
        }
        return msg;
    };
}

})(jQuery);

==> archibald-7.x-2.1.tar.gz: archibald/js/prohibit_double_edit.js <==
var archibald_prohibit_double_edit_interval=0;

/**
 * ping for updating editor last seen bit
 * will called by interval every 3 minutes
 **/
function archibald_prohibit_double_edit_ping()
{
    jQuery.get(Drupal.settings.archibald_prohibit_double_edit.url_ping, function() { } );
}

(function ($) {

Drupal.behaviors.archibald_prohibit_double_edit = {
  attach: function (context, settings) {
    archibald_prohibit_double_edit(settings);

    if (Drupal.settings.archibald_prohibit_double_edit.form_blur_message==true) {
        archibald_form_blur_message();
    }
  }
};

/**
* check if resource is currently edited by other user
* by using Drupal.settings
* and display message dialog in case
* or start interval ping to update editor last seen bit in db
*/
function archibald_prohibit_double_edit(settings) {
    if (settings.archibald_prohibit_double_edit.free!=1) {
        var last_seen = new Date(settings.archibald_prohibit_double_edit.last_seen*1000);

        archibald_prohibit_double_edit_dialog( Drupal.t('User: "@username" <br> is editing this node since <br> "@time"',
              { '@username': settings.archibald_prohibit_double_edit.user,
                '@time':     last_seen.toLocaleString()
              } )
             );

    } else {
        archibald_prohibit_double_edit_init();
    }
}

/**
 * start ping interval
 * to update editor last seen bit in db
 **/
function archibald_prohibit_double_edit_init() {
    archibald_prohibit_double_edit_ping();

    if (archibald_prohibit_double_edit_interval==undefined) {
        // work arround for for ajax initer
        return false;
    }

    // ping alle 3 Minutes that you still edit this node
    archibald_prohibit_double_edit_interval = window.setInterval("archibald_prohibit_double_edit_ping()", (1000*60*3));

    $('.archibald_form_submit').click(archibald_prohibit_double_edit_checkout); // form save button
    $('.tabs .primary li span' ).click(archibald_prohibit_double_edit_checkout); // primary tabs like "view", "translate", "delete" ,"revisions"

    $(window).unload(function() {
        archibald_prohibit_double_edit_checkout();
    });
}

/**
 * reset editor last seen bit
 * call this wenn leveing editing mode
 **/
function archibald_prohibit_double_edit_checkout()
{
    $.get(Drupal.settings.archibald_prohibit_double_edit.url_checkout, function() { } );

    window.clearInterval(archibald_prohibit_double_edit_interval);
    archibald_prohibit_double_edit_interval = 0;
}

/**
 * dsiplay a info dialog
 * with history.back() on closing
 *
 * @param message strng
 */
function archibald_prohibit_double_edit_dialog( message )
{
    var dialog_div = $('<div></div>');
    dialog_div.attr('title', Drupal.t('Double editing info'));

    dialog_div.append('<p>'+message+'</p>');

    var dialog_buttons = new Object();
    dialog_buttons[Drupal.t('back')] = function() {
        window.history.back();
      };

    dialog_div.dialog({ buttons:dialog_buttons, modal:true });

    dialog_div.bind( "dialogbeforeclose", function(event, ui) {
        window.history.back();
        return false;
      });
}

/**
 *  display warning when user leave withou saving
 *  This will only work in modern versions of InternetExplorer and Firefox
 *  @see https://developer.mozilla.org/en/DOM/window.onbeforeunload
 */
function archibald_form_blur_message() {
    $('#archibald-content-form input').bind('change',    function () { $(window).bind('beforeunload' ,archibald_form_blur_message_unload_msg); } );
    $('#archibald-content-form textarea').bind('change', function () { $(window).bind('beforeunload' ,archibald_form_blur_message_unload_msg); } );
    $('#archibald-content-form select').bind('change',   function () { $(window).bind('beforeunload' ,archibald_form_blur_message_unload_msg); } );

    $('.archibald_form_submit').click( function () {  $(window).unbind('beforeunload');  } );

    function archibald_form_blur_message_unload_msg(e) {
        e = e || window.event;

        var msg = Drupal.t('Do you really like to leave without saving?');
        if (e) {
            e.returnValue = msg;
        }
        return msg;
    };
}

})(jQuery);
